@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettings.py 10849 2018-03-14 10:07:27Z David $
+# $Id: AttachSettings.py 11587 2019-05-28 01:38:04Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-14 18:07:27 +0800 (週三, 14 三月 2018) $
-# $Revision: 10849 $
+# $Author: Andy $
+# $Date: 2019-05-28 09:38:04 +0800 (週二, 28 五月 2019) $
+# $Revision: 11587 $
 
 import os
 
@@ -43,7 +43,91 @@ def attachSettings(settingsDict):
         templateDirs = list(settingsDict['TEMPLATES'][0]['DIRS'])
         templateDirs.extend([THEOPHRASTUS_TEMPLATE_DIRS])
         settingsDict['TEMPLATES'][0]['DIRS'] = tuple(templateDirs)
+        
+        
+        #=======================================================================
+        # Attach STATIC_DIRS.
+        #=======================================================================
+        THEOPHRUSTUS_STATIC_DIRS = settingsDict.get(
+             'THEOPHRUSTUS_STATIC_DIRS',
+             os.path.join(CURRENT_PATH, 'static')
+             )    
+        staticDirs = list(settingsDict['STATICFILES_DIRS'])
+        staticDirs.extend([THEOPHRUSTUS_STATIC_DIRS])
+        settingsDict['STATICFILES_DIRS'] = tuple(staticDirs)
+        
+        
+        #=======================================================================
+        # Attach TINYMCE_DEFAULT_CONFIG.
+        #=======================================================================        
+        if not settingsDict.has_key('TINYMCE_DEFAULT_CONFIG'):
+            settingsDict['TINYMCE_DEFAULT_CONFIG'] = {
+                'plugins':
+                    "facebook,autolink,lists,spellchecker,pagebreak,style,layer,table,save"
+                    ",advhr,advimage,advlink,emotions,iespell,inlinepopups,"
+                    "insertdatetime,preview,media,searchreplace,print,contextmenu,"
+                    "paste,directionality,fullscreen,noneditable,visualchars,"
+                    "nonbreaking,xhtmlxtras,template,upload,variablePlugin",
+                'relative_urls': False,
+                'remove_script_host': False,
+                'skin_variant': "black",
+                'style_formats': [{
+                    'title' : 'Bold text',
+                    'inline' : 'b'
+                }, {
+                    'title' : 'Red text',
+                    'inline' : 'span',
+                    'styles' : {'color' : '#ff0000'}
+                }, {
+                    'title' : 'Red header',
+                    'block' : 'h1',
+                    'styles' : {'color' : '#ff0000'}
+                }],
 
+                #'formats': {"test": {"title" : 'Table row 1', "selector" : 'tr', "classes" : 'tablerow1'}},
+                'theme': "advanced",
+                'theme_advanced_buttons1': "save,newdocument,|,bold,italic,underline,"
+                                           "strikethrough,|,justifyleft,justifycenter,"
+                                           "justifyright,justifyfull,|,styleselect,"
+                                           "formatselect,fontselect,fontsizeselect,"
+                                           "template,|,link,unlink,image,|,",
+                'theme_advanced_buttons2': "cut,copy,paste,pastetext,pasteword,|,search,"
+                                           "replace,|,bullist,numlist,|,outdent,indent,"
+                                           "blockquote,|,undo,redo,|,"
+                                           "upload,cleanup,code,|,insertdate,"
+                                           "inserttime,preview,|,forecolor,backcolor",
+                'theme_advanced_buttons3': "tablecontrols,|,hr,removeformat,visualaid,|,"
+                                           "sub,sup,|,charmap,iespell,media,advhr,|,"
+                                           "insertlayer,moveforward,movebackward,absolute,"
+                                           "|,styleprops,spellchecker,",
+                'theme_advanced_buttons4': "fullscreen,print,feed,variablePlugin,|,",
+                'theme_advanced_toolbar_location': "top",
+                'theme_advanced_toolbar_align': "left",
+                'theme_advanced_statusbar_location': "bottom",
+                'theme_advanced_resizing': True,
+
+                # Skin options
+                'skin': "o2k7",
+                'skin_variant': "silver",
+
+                # Example content CSS (should be your site CSS)
+                #'content_css' : "css/example.css",
+
+                # Drop lists for link/image/media/template dialogs
+                #'template_external_list_url': "%sjs/TemplateExternalList.js" % MEDIA_URL,
+                #'external_link_list_url': "js/link_list.js",
+                #'external_image_list_url': "js/image_list.js",
+                #'media_external_list_url': "js/media_list.js",
+
+                # Replace values for the template plugin
+                'template_replace_values': {
+                    'username': "Some User",
+                    'staffid': "991234"
+                },
+
+                'template_templates': [],
+            }
+        
         #=======================================================================
         # Attach INSTALLED_APPS.
         #=======================================================================
