@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 11540 2019-05-12 11:10:35Z Andy $
+# $Id: Mailer.py 11573 2019-05-22 07:55:28Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: Andy $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 11540 $
+# $Revision: 11573 $
 
 import os
 import re
@@ -106,7 +106,7 @@ class CloudSMTP(object):
         mail = None
         try:
             backend = EmailBackend(fallback=False)
-            
+
             contentHtml = content
             contentText = html2text(contentHtml)
 
@@ -221,21 +221,35 @@ class CloudMailer(Mailer):
 
         if self.test:
             return True
-            
+
         # can't compare offset-naive and offset-aware datatimes
         now = timezone.now()
-        if self.newsletter.sending_date <= now and \
-               (self.newsletter.status == Newsletter.WAITING):
-            return True
+        if isinstance(self.newsletter.sending_date, datetime):
+            if self.newsletter.sending_date <= datetime.now() and \
+                (self.newsletter.status == Newsletter.WAITING):
+                return True
 
-        self.logger.info(
-            ('[%d]_[can_send]_CANNOT: Newsletter(status: %d) can not send:'
-             'sending_date: %s, datetime.now: %s (TZ: %s).') %
-            (self.newsletter.id, self.newsletter.status,
-             self.newsletter.sending_date, now,
-             os.environ.get('TZ', 'None')))
+            self.logger.info(
+                ('[%d]_[can_send]_CANNOT: Newsletter(status: %d) can not send:'
+                 'sending_date: %s, datetime.now: %s (TZ: %s).') %
+                (self.newsletter.id, self.newsletter.status,
+                 self.newsletter.sending_date, datetime.now(),
+                 os.environ.get('TZ', 'None')))
 
-        return False
+            return False
+        else:
+            if self.newsletter.sending_date <= now and \
+                   (self.newsletter.status == Newsletter.WAITING):
+                return True
+
+            self.logger.info(
+                ('[%d]_[can_send]_CANNOT: Newsletter(status: %d) can not send:'
+                 'sending_date: %s, datetime.now: %s (TZ: %s).') %
+                (self.newsletter.id, self.newsletter.status,
+                 self.newsletter.sending_date, now,
+                 os.environ.get('TZ', 'None')))
+
+            return False
 
     def testSend(self, contact, wait=5):
         """
@@ -304,7 +318,7 @@ class CloudMailer(Mailer):
             image_tracking = render_to_string(
                 'newsletter/newsletter_image_tracking.html', context)
             content = body_insertion(content, image_tracking, end=True)
-        
+
         return smart_unicode(content)
 
     def send(self, contact):
@@ -339,11 +353,11 @@ class CloudMailer(Mailer):
                     contentHtml,
                     attachments=self.attachments)
                 resultMessage = 'Send mail success.'
-                
+
             else:
                 message = self.build_message(contact)
-                
-                with self.smtpLock:    
+
+                with self.smtpLock:
                     self.smtp.sendmail(
                         smart_str(self.newsletter.header_sender),
                         contact.email,
@@ -371,7 +385,7 @@ class CloudMailer(Mailer):
 
             # Record error message  to db.
             ErrorMessage.objects.create(
-                message=(resultMessage + _eMsg), 
+                message=(resultMessage + _eMsg),
                 contact=contact,
                 newsletter=self.newsletter
             )
@@ -411,7 +425,7 @@ class CloudMailer(Mailer):
 
             # Record error message  to db.
             ErrorMessage.objects.create(
-                message=(resultMessage + errorMessage), 
+                message=(resultMessage + errorMessage),
                 contact=contact,
                 newsletter=self.newsletter
             )
@@ -495,21 +509,21 @@ class CloudMailer(Mailer):
 
             s = ('[%d][run]_FAILED: %s,' % (newsletterId, _s))
             if isinstance(e, NoResultsPending):
-                self.logger.error('%s reason: NoResultsPending, %s.' % 
+                self.logger.error('%s reason: NoResultsPending, %s.' %
                                  (s, str(e)))
             elif isinstance(e, NoWorkersAvailable):
-                self.logger.error('%s reason: NoWorkersAvailable, %s.' % 
+                self.logger.error('%s reason: NoWorkersAvailable, %s.' %
                                  (s, str(e)))
             else:
                 self.logger.error('%s reason: %s.' % (s, getComment(e)))
         finally:
-                       
+
             if self.smtp:
                 if self.pool:
                     self.pool.wait()
                 self.smtp.quit()
-                
-            self.update_newsletter_status()                
+
+            self.update_newsletter_status()
 
             if self.pool:
                 _s = 'Put worker to pool over.'
