@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 11006 2018-05-01 07:48:58Z Kevin $
+# $Id: StatisticsHandler.py 11555 2019-05-16 07:37:39Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Kevin $
-# $Date: 2018-05-01 15:48:58 +0800 (週二, 01 五月 2018) $
-# $Revision: 11006 $
+# $Author: Andy $
+# $Date: 2019-05-16 15:37:39 +0800 (週四, 16 五月 2019) $
+# $Revision: 11555 $
 
 from datetime import timedelta, datetime
 
@@ -57,7 +57,7 @@ if settings.DATABASE_ENGINE == 'mysql':
         for ele in row:
             if "strftime" in ele:
                 setNewMysqlFunc = False
-        
+
         if setNewMysqlFunc:
             cursor.execute(
                 """
@@ -80,10 +80,10 @@ def getDateRange(startDate, endDate):
     if isinstance(endDate, str):
         if endDate != "NaN":
             endDate = datetime.strptime(endDate, '%Y-%m-%d %H:%M:%S')
-    
-    deltaDays = endDate - startDate 
+
+    deltaDays = endDate - startDate
     daysAmount = deltaDays.days + 1
-    
+
     def _createDate(daysAmount):
         days = [startDate.strftime('%Y-%m-%d')]
         for i in range(1, daysAmount):
@@ -96,7 +96,7 @@ def getDateRange(startDate, endDate):
                 self._days = days
                 self.startDate = '%s 00:00:00' % days[0]
                 self.endDate = '%s 23:59:59' % days[-1]
-                
+
         return DateRange(days)
 
     return _createDate(daysAmount)
@@ -328,7 +328,7 @@ def countStatus(queryset, historyMode='general'):
     bouncedLogs = set()
     complainLogs = set()
     rejectedLogs = set()
-    
+
     for (id, status) in [(i['contact'], i['status']) for i in queryset]:
         if status == ContactMailingStatus.SENT_TEST:
             sentTestNumber.add(id)
@@ -339,22 +339,22 @@ def countStatus(queryset, historyMode='general'):
         elif status == ContactMailingStatus.INVALID:
             invaildLogs.add(id)
         elif status == ContactMailingStatus.UNSUBSCRIPTION:
-            unsubscriptionNumber.add(id)        
+            unsubscriptionNumber.add(id)
         elif status == ContactMailingStatus.OPENED:
             openLogs.add(id)
-            openId.append(id)     
+            openId.append(id)
         elif status == ContactMailingStatus.OPENED_ON_SITE:
             openOnSiteLogs.add(id)
             openOnSiteId.append(id)
             if not id in openLogs:
                 openLogs.add(id)
-                openId.append(id)              
+                openId.append(id)
         elif status == ContactMailingStatus.LINK_OPENED:
             clickLogs.add(id)
             clickId.append(id)
             if not id in openLogs:
                 openLogs.add(id)
-                openId.append(id)  
+                openId.append(id)
         ##
         elif status == ContactMailingStatus.BOUNCED:
             bouncedLogs.add(id)
@@ -362,10 +362,10 @@ def countStatus(queryset, historyMode='general'):
             complainLogs.add(id)
         elif status == ContactMailingStatus.REJECTED:
             rejectedLogs.add(id)
-    
+
     # formula reference: emencia.django.utils.statistics.py
     # openings
-#     openings = queryset.filter(Q(status=ContactMailingStatus.OPENED) | 
+#     openings = queryset.filter(Q(status=ContactMailingStatus.OPENED) |
 #                                Q(status=ContactMailingStatus.OPENED_ON_SITE))
 #     openingsByLinks = len(
 #         set(queryset.filter(status=ContactMailingStatus.LINK_OPENED).exclude(
@@ -373,13 +373,13 @@ def countStatus(queryset, historyMode='general'):
 #     ).values_list('contact', flat=True)))
 #     uniqueOpenings = len(set(openings.values_list('contact', flat=True))) + \
 #                      openingsByLinks
-#                           
+#
 #     # on site openings
 #     onSiteOpenings = queryset.filter(
 #        status=ContactMailingStatus.OPENED_ON_SITE)
 #     uniqueOnSiteOpenings = len(set(onSiteOpenings.values_list(
 #                               'contact', flat=True)))
-#             
+#
 #     # clicked
 #     clickedLinks = queryset.filter(status=ContactMailingStatus.LINK_OPENED)
 #     uniqueClicked = len(set(clickedLinks.values_list(
@@ -397,13 +397,13 @@ def countStatus(queryset, historyMode='general'):
                 'unsubscribe': len(unsubscriptionNumber),
                 'bounce': len(bouncedLogs),
                 'complain': len(complainLogs),
-                'reject': len(rejectedLogs),        
+                'reject': len(rejectedLogs),
             },
             {
                 'openId': openId,
                 'openOnSiteId': openOnSiteId,
                 'clickId': clickId
-            }            
+            }
         ]
     else:
         return [
@@ -418,13 +418,13 @@ def countStatus(queryset, historyMode='general'):
                 'unsubscribe': len(unsubscriptionNumber),
                 'bounce': len(bouncedLogs),
                 'complain': len(complainLogs),
-                'reject': len(rejectedLogs),        
+                'reject': len(rejectedLogs),
             },
             {
                 'openId': openId,
                 'openOnSiteId': openOnSiteId,
                 'clickId': clickId
-            }            
+            }
         ]
 
 from django.db.models import Q
@@ -438,15 +438,15 @@ def getStartDateEndDate():
                ].creation_date.strftime('%Y-%m-%d')
     return startDate, endDate
 
-def getAllDataDate():    
+def getAllDataDate():
     firstDate = ContactMailingStatus.objects.order_by('creation_date')[0
                 ].creation_date
     lastDate = ContactMailingStatus.objects.order_by('-creation_date')[0
                ].creation_date
-    
+
     deltaDays = lastDate - firstDate + timedelta(1)
-    daysAmount = deltaDays.days + 1    
-    
+    daysAmount = deltaDays.days + 1
+
     days = [firstDate.strftime('%Y-%m-%d')]
     for i in range(1, daysAmount):
         d = firstDate + timedelta(days=i)
@@ -458,33 +458,33 @@ def getAllDataDate():
             self._days = days
             self.startDate = '%s 00:00:00' % days[0]
             self.endDate = '%s 23:59:59' % days[-1]
-            
+
     return DateRange(days)
 
-def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount, 
+def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                            conditions):
     """
     Get statistics of subscriber's every rates.
-    Data for line chart. 
+    Data for line chart.
 
     @param slug Newsletter slug.
     @param request Request instance.
     """
-    
+
     dataType = reqestGetData.get('dataType', 'number')
     mode = reqestGetData.get('mode', 'accumulate')
     historyMode = reqestGetData.get('historyMode', 'general')
     allDataDates = getAllDataDate()
-    
+
 #     period = reqestGetData.get('period', 'week')
-# 
+#
 #     _firstCreationDate = ContactMailingStatus.objects.filter(**conditions)
 #     _s = {"d": "strftime('%%Y-%%m-%%d', creation_date)"}
 #     _firstCreationDate = _firstCreationDate.extra(_s)
 #     _firstCreationDate = _firstCreationDate.values('d').distinct().order_by('d')
 #     _t = datetime.strptime(_firstCreationDate[0]['d'], '%Y-%m-%d')
 #     dates = getDateRange(period, defaultStart=_t)
-    
+
 
     def getContactStatus(conditions, history):
         contactStatus = ContactMailingStatus.objects.filter(**conditions)
@@ -504,14 +504,14 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
 
     def sortByDatetime(contactStatus):
         completed = OrderedDict()
-        
+
         dates = []
         for c in contactStatus:
-            date = c['d']            
+            date = c['d']
             if not date in dates:
                 dates.append(date)
         dates = sorted(dates)
-        
+
         for date in dates:
             year = date.split('-')[0]
             month = date.split('-')[1]
@@ -524,13 +524,13 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
 
     # -- get all date content -------------------------------------------------
     conditions.update(
-        {'creation_date__range': [allDataDates.startDate, 
+        {'creation_date__range': [allDataDates.startDate,
                                   allDataDates.endDate]})
-    
+
     if 'newsletter__id__in' in conditions:
         newsletterIds = conditions.pop('newsletter__id__in')
 
-        
+
         allDates = []
         allNewslettersData = []
         openIds = []
@@ -542,9 +542,9 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
             conditions.update({'newsletter__id': _id})
             _cs = getContactStatus(conditions, historyMode)
             if _cs:
-                # _cs:[ {'status': 0, 'contact': 5, 'd': u'2018-01-04'}, 
+                # _cs:[ {'status': 0, 'contact': 5, 'd': u'2018-01-04'},
                 # {'status': 4, 'contact': 5, 'd': u'2018-01-07'}...]
-                
+
                 for ele in _cs:
                     contactId = ele['contact']
                     _dateKey = ele['d']
@@ -558,7 +558,7 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                             _statusCount['open'] = 0
                         else:
                             openIds.append(contactId)
-                    if _statusCount['openOnSite']:        
+                    if _statusCount['openOnSite']:
                         if contactId in openOnSiteIds and historyMode == 'general':
                             _statusCount['openOnSite'] = 0
                         else:
@@ -604,28 +604,28 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                 open = _d[1]['openId']
                 openOnSite = _d[1]['openOnSiteId']
                 link = _d[1]['clickId']
-                
+
                 openCount = 0
                 openOnSiteCount = 0
                 linkCount = 0
-                
+
                 for id in open:
                     if not id in openIds:
                         if not id in openOnSiteIds:
                             if not id in linkIds:
                                 openIds.append(id)
                                 openCount += 1
-                                
+
                 for id in openOnSite:
                     if not id in openOnSiteIds:
                         openOnSiteIds.append(id)
                         openOnSiteCount += 1
-                        
+
                 for id in link:
                     if not id in linkIds:
                         linkIds.append(id)
                         linkCount += 1
-                        
+
                 data = _d[0]
                 data['open'] = openCount
                 data['openOnSite'] = openOnSiteCount
@@ -633,7 +633,7 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                 totalData.append([c, data])
 
     allDates = sorted(dict(totalData).keys())
-    for day in allDataDates._days:        
+    for day in allDataDates._days:
         if day not in allDates:
             totalData.append([day, getEmptyDataStructure()])
     totalData = sorted(totalData)
@@ -652,16 +652,16 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                     accumulativeData[status] += data[status]
                     result.append((status, accumulativeData[status]))
                 allContent[day] = result
-        
+
     else:
         def _do(info, subscriberCount, testSubscriberCount):
             rates = []
             newsletter = conditions.get('newsletter', None)
             if newsletter:
                 totalSentNewsletter = ContactMailingStatus.objects.filter(
-                                    newsletter=newsletter, 
+                                    newsletter=newsletter,
                                     status=ContactMailingStatus.SENT
-                                ).count()   
+                                ).count()
             else:
                 totalSentNewsletter = subscriberCount
             for i in info:
@@ -670,17 +670,17 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                 elif i == 'sentTest':
                     totalValue = testSubscriberCount
                 else:
-                    totalValue = totalSentNewsletter 
-                
+                    totalValue = totalSentNewsletter
+
                 value = percentage(info[i], totalValue, showPercent=False)
-                
+
                 rates.append((i, value))
             return rates
-        
+
         if mode == 'single':
             for (day, data) in totalData:
                 result = _do(data, subscriberCount, testSubscriberCount)
-                allContent[day] = result 
+                allContent[day] = result
                 # {'day': (status, value)}
                 # {'2017-12-25': [('invaild', 0.0), ('sentTest', 0.0), ...]}
         else:
@@ -697,24 +697,24 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                     accResult.append(_result)
                 allContent[day] = accResult
     # -- get all date content end ----------------------------------------------
-    
+
     # -- get range date content start ------------------------------------------
     deltaDays = None
-    
+
     startDate = reqestGetData.get('startDate', None)
     if isinstance(startDate, str) or isinstance(startDate, unicode):
         if startDate != "NaN":
-            startDate = datetime.strptime(startDate, '%Y/%m/%d') 
+            startDate = datetime.strptime(startDate, '%Y/%m/%d')
 
-    endDate = reqestGetData.get('endDate', None) 
+    endDate = reqestGetData.get('endDate', None)
     if isinstance(endDate, str) or isinstance(endDate, unicode):
         if endDate != "NaN":
-            endDate = datetime.strptime(endDate, '%Y/%m/%d') 
-    
-    period = reqestGetData.get('period', 'week')    
+            endDate = datetime.strptime(endDate, '%Y/%m/%d')
+
+    period = reqestGetData.get('period', 'week')
     if period == 'week':
         deltaDays = 6
-        endDate = datetime.now()        
+        endDate = datetime.now()
         startDate = endDate - timedelta(days=deltaDays)
     elif period == 'month':
         deltaDays = int(1 * (365 / 12))
@@ -725,7 +725,7 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
         endDate = datetime.now()
         startDate = endDate - timedelta(days=deltaDays)
     dateRange = getDateRange(startDate, endDate)
-    
+
     content = {}
     _days = dateRange._days
     lastDate = allDates[-1]
@@ -734,8 +734,8 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
         if _d in allContent.keys():
             content[_d] = allContent[_d]
         else:
-            _emptyData = getEmptyDataStructure()            
-            if mode == 'single':    
+            _emptyData = getEmptyDataStructure()
+            if mode == 'single':
                 if dataType == 'number':
                     content[_d] = [(i, _emptyData[i]) for i in _emptyData]
                 else:
@@ -748,17 +748,17 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
                     if dataType == 'number':
                         content[_d] = [(i, _emptyData[i]) for i in _emptyData]
                     else:
-                        content[_d] = [(i, 0.0) for i in _emptyData]              
+                        content[_d] = [(i, 0.0) for i in _emptyData]
    # -- get range date content end --------------------------------------------
-    
-    
+
+
     context = {}
     for day in content:
         for (statusName, value) in content[day]:
             dData = context.get(statusName, [])
             dData.append((day, value))
             context[statusName] = dData
-                
+
     # Find the max value of Y-axis.
     tmp = []
     for k in context:
@@ -768,6 +768,11 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     yaxisMaxValue = max(tmp)
     del tmp
 
+
+    _STATUS_NAMES = []
+    for i in STATUS_NAMES:
+        _STATUS_NAMES.append(unicode(i))
+
     response = {
         'context': {
             'email': context,
@@ -778,7 +783,7 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
         'yaxis': {'max': yaxisMaxValue},
         'status': _STATUS,
         'settings': {
-            'labels': STATUS_NAMES,
+            'labels': _STATUS_NAMES,
         },
     }
     return response
@@ -801,9 +806,9 @@ def getStatisticsTotalRateData(reqestGetData, subscriberCount,
         #contactStatus = contactStatus.order_by().values(
         #    'contact', 'status').distinct(['contact', 'status'])
         contactStatus = contactStatus.order_by().values(
-            'contact', 'status').distinct()        
+            'contact', 'status').distinct()
         # [{'status': 0, 'contact': 1}, {'status': 4, 'contact': 1}, ...]
-        return contactStatus   
+        return contactStatus
 
     if 'newsletter__id__in' in conditions:
         newsletterIds = conditions.pop('newsletter__id__in')
@@ -811,7 +816,7 @@ def getStatisticsTotalRateData(reqestGetData, subscriberCount,
         for _id in newsletterIds:
             conditions.update({'newsletter__id': _id})
             _cs = getContactStatus(conditions)
-            
+
             _data = countStatus(_cs)[0]
             for _d in _data:
                 v = _data[_d]
@@ -823,30 +828,34 @@ def getStatisticsTotalRateData(reqestGetData, subscriberCount,
         data = countStatus(contactStatus)[0]
 
     rates = []
-    
+
     totalValue = 0
-    
+
     for d in data:
         totalValue += data[d]
-    
-    
+
+
     for d in data:
         if d in ('unsubscribe', 'deliverie', 'error'):
             totalValue = subscriberCount
         elif d == 'sentTest':
             totalValue = testSubscriberCount
         else:
-            totalValue = data['deliverie']        
+            totalValue = data['deliverie']
 
         value = percentage(data[d], totalValue)
-        
+
         rates.append((d, value))
 
+    _STATUS_NAMES = []
+    for i in STATUS_NAMES:
+        _STATUS_NAMES.append(unicode(i))
+
     response = {
         'context': dict(rates),
         'contextCount': data,
         'status': _STATUS,
-        'statusNames': STATUS_NAMES,
+        'statusNames': _STATUS_NAMES,
     }
     return response
 
